FileMetadata

Struct FileMetadata 

pub struct FileMetadata<'a> {
    pub size: usize,
    pub compressed_size: usize,
    pub compression_method: CompressionMethod,
    pub crc32: u32,
    pub encrypted: bool,
    pub path: Cow<'a, Utf8Path>,
    pub last_modified: NaiveDateTime,
    pub unix_mode: Option<u16>,
    /* private fields */
}
Metadata for a file or directory in the archive, retrieved from its central directory

Fields

size: usize

Uncompressed size of the file in bytes

compressed_size: usize

Compressed size of the file in bytes

compression_method: CompressionMethod

Compression algorithm used to store the file

crc32: u32

The CRC-32 of the decompressed file

encrypted: bool

True if the file is encrypted (decryption is unsupported)

path: Cow<'a, Utf8Path>

The provided path of the file.

last_modified: NaiveDateTime

The ISO 8601 combined date and time the file was last modified

unix_mode: Option<u16>

Unix mode bits, if the file was archived in a Unix OS.

This library does not try to convert DOS permission bits into roughly-equivalent Unix mode bits, or do other cross-OS handwaving. Future versions might provide an enum here of different OS’s metadata.

Implementations

Source

impl<'a> FileMetadata<'a>

pub fn is_dir(&self) -> bool

Returns true if the given entry is a directory

pub fn is_file(&self) -> bool

Returns true if the given entry is a file

pub fn into_owned(self) -> FileMetadata<'static>