ZipArchive

Struct ZipArchive 

pub struct ZipArchive<'a> { /* private fields */ }
A ZIP archive to be read

Implementations

Source

impl<'a> ZipArchive<'a>

pub fn new(mapping: &'a [u8]) -> ZipResult<Self>

Reads a ZIP archive from a byte slice. Smaller files can be read into a buffer.

let bytes = fs::read("foo.zip")?;
let archive = ZipArchive::new(&bytes)?;

For larger ones, memory map!

let zip_file = File::open("foo.zip")?;
let mapping = unsafe { Mmap::map(&zip_file)? };
let archive = ZipArchive::new(&mapping)?;
pub fn with_prepended_data(mapping: &'a [u8]) -> ZipResult<(Self, usize)>

Like ZipArchive::new(), but allows arbitrary data to prepend the archive. Returns the ZipArchive and the number of bytes prepended to the archive.

Since a ZIP archive’s metadata sits at the back of the file, many formats consist of ZIP archives prepended with some other data. For example, a self-extracting archive is one with an executable in the front.

pub fn entries(&self) -> &[FileMetadata<'_>]

Returns the entries found in the ZIP archive’s central directory.

No effort is made to deduplicate or otherwise validate these entries. To do that, create a FileTree.

pub fn read( &self, metadata: &FileMetadata<'_>, ) -> ZipResult<Box<dyn Read + Send + 'a>>

Reads the given file from the ZIP archive.

Since each file in a ZIP archive is compressed independently, multiple files can be read in parallel.